simsopt.field package
=====================

Submodules
----------

simsopt.field.biotsavart module
-------------------------------

.. automodule:: simsopt.field.biotsavart
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.field.boozermagneticfield module
----------------------------------------

.. automodule:: simsopt.field.boozermagneticfield
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.field.coil module
-------------------------

.. automodule:: simsopt.field.coil
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.field.magneticfield module
----------------------------------

.. automodule:: simsopt.field.magneticfield
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.field.magneticfieldclasses module
-----------------------------------------

.. automodule:: simsopt.field.magneticfieldclasses
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.field.mgrid module
--------------------------

.. automodule:: simsopt.field.mgrid
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.field.normal\_field module
----------------------------------

.. automodule:: simsopt.field.normal_field
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.field.sampling module
-----------------------------

.. automodule:: simsopt.field.sampling
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.field.tracing module
----------------------------

.. automodule:: simsopt.field.tracing
   :members:
   :undoc-members:
   :show-inheritance:

